pub struct RgbicLightStripHandler { /* private fields */ }Implementations
Sourceimpl RgbicLightStripHandler
impl RgbicLightStripHandler
Sourcepub async fn refresh_session(&mut self) -> Result<&mut Self, Error>
pub async fn refresh_session(&mut self) -> Result<&mut Self, Error>
Refreshes the authentication session.
Sourcepub async fn get_device_info(
&self,
) -> Result<DeviceInfoRgbicLightStripResult, Error>
pub async fn get_device_info( &self, ) -> Result<DeviceInfoRgbicLightStripResult, Error>
Returns device info as DeviceInfoRgbicLightStripResult.
It is not guaranteed to contain all the properties returned from the Tapo API.
If the deserialization fails, or if a property that you care about it’s not present, try [RgbicLightStripHandler::get_device_info_json].
Sourceimpl RgbicLightStripHandler
impl RgbicLightStripHandler
Sourcepub async fn get_device_usage(
&self,
) -> Result<DeviceUsageEnergyMonitoringResult, Error>
pub async fn get_device_usage( &self, ) -> Result<DeviceUsageEnergyMonitoringResult, Error>
Returns device usage as DeviceUsageEnergyMonitoringResult.
Sourceimpl RgbicLightStripHandler
impl RgbicLightStripHandler
Sourcepub async fn device_reboot(&self, delay_s: u16) -> Result<(), Error>
pub async fn device_reboot(&self, delay_s: u16) -> Result<(), Error>
Reboots the device.
Notes:
- Using a very small delay (e.g. 0 seconds) may cause a
ConnectionResetorTimedOuterror as the device reboots immediately. - Using a larger delay (e.g. 2-3 seconds) allows the device to respond before rebooting, reducing the chance of errors.
- With larger delays, the method completes successfully before the device reboots. However, subsequent commands may fail if sent during the reboot process or before the device reconnects to the network.
Arguments
delay_s- The delay in seconds before the device is rebooted.
Sourcepub async fn device_reset(&self) -> Result<(), Error>
pub async fn device_reset(&self) -> Result<(), Error>
Hardware resets the device.
Warning: This action will reset the device to its factory settings. The connection to the Wi-Fi network and the Tapo app will be lost, and the device will need to be reconfigured.
This feature is especially useful when the device is difficult to access and requires reconfiguration.
Sourceimpl RgbicLightStripHandler
impl RgbicLightStripHandler
Sourcepub fn set(&self) -> ColorLightSetDeviceInfoParams
pub fn set(&self) -> ColorLightSetDeviceInfoParams
Returns a ColorLightSetDeviceInfoParams builder that allows multiple properties to be set in a single request.
ColorLightSetDeviceInfoParams::send must be called at the end to apply the changes.
For lighting effects, use RgbicLightStripHandler::set_lighting_effect instead.
Example
device
.set()
.brightness(50)
.color(Color::HotPink)
.send(&device)
.await?;Sourcepub async fn set_brightness(&self, brightness: u8) -> Result<(), Error>
pub async fn set_brightness(&self, brightness: u8) -> Result<(), Error>
Sets the brightness and turns on the device. Pre-existing lighting effect will be removed.
Arguments
brightness- between 1 and 100
Sourcepub async fn set_color(&self, color: Color) -> Result<(), Error>
pub async fn set_color(&self, color: Color) -> Result<(), Error>
Sets the color and turns on the device. Pre-existing lighting effect will be removed.
Arguments
color- one of crate::requests::Color as defined in the Google Home app
Sourcepub async fn set_hue_saturation(
&self,
hue: u16,
saturation: u8,
) -> Result<(), Error>
pub async fn set_hue_saturation( &self, hue: u16, saturation: u8, ) -> Result<(), Error>
Sets the hue, saturation and turns on the device. Pre-existing lighting effect will be removed.
Arguments
hue- between 0 and 360saturation- between 1 and 100
Sourcepub async fn set_color_temperature(
&self,
color_temperature: u16,
) -> Result<(), Error>
pub async fn set_color_temperature( &self, color_temperature: u16, ) -> Result<(), Error>
Sets the color temperature and turns on the device. Pre-existing lighting effect will be removed.
Arguments
color_temperature- between 2500 and 6500
Sourcepub async fn set_lighting_effect(
&self,
lighting_effect: impl Into<LightingEffect>,
) -> Result<(), Error>
pub async fn set_lighting_effect( &self, lighting_effect: impl Into<LightingEffect>, ) -> Result<(), Error>
Sets a lighting effect and turns on the device.
Arguments
lighting_effect- crate::requests::LightingEffectPreset or a custom crate::requests::LightingEffect.
Sourcepub async fn set_segment_effect(
&self,
segment_effect: impl Into<SegmentEffect>,
) -> Result<(), Error>
pub async fn set_segment_effect( &self, segment_effect: impl Into<SegmentEffect>, ) -> Result<(), Error>
Sets a segment effect and turns on the device.
This is used for the newer app-defined RGBIC strip effects that cannot be set by
LightingEffect (for example, “circulating” or “breathe” segment effects).
Arguments
segment_effect- acrate::requests::SegmentEffectPresetor a customSegmentEffect