pub struct S210Handler { /* private fields */ }Expand description
Handler for the S210 devices.
Implementations
Sourceimpl S210Handler
impl S210Handler
Sourcepub async fn get_device_info(&self) -> Result<S210Result, Error>
pub async fn get_device_info(&self) -> Result<S210Result, Error>
Returns device info as S210Result.
It is not guaranteed to contain all the properties returned from the Tapo API.
If the deserialization fails, or if a property that you care about it’s not present, try [S210Handler::get_device_info_json].
Sourceimpl S210Handler
impl S210Handler
Sourceimpl S210Handler
impl S210Handler
Sourcepub async fn get_device_usage(&self) -> Result<DeviceUsageResult, Error>
pub async fn get_device_usage(&self) -> Result<DeviceUsageResult, Error>
Returns device usage as DeviceUsageResult.