pub struct T100Handler { /* private fields */ }Expand description
Handler for the T100 devices.
Implementations
Sourceimpl T100Handler
impl T100Handler
Sourcepub async fn get_device_info(&self) -> Result<T100Result, Error>
pub async fn get_device_info(&self) -> Result<T100Result, Error>
Returns device info as T100Result.
It is not guaranteed to contain all the properties returned from the Tapo API.
Sourcepub async fn get_device_info_json(&self) -> Result<Value, Error>
pub async fn get_device_info_json(&self) -> Result<Value, Error>
Returns device info as serde_json::Value.
It contains all the properties returned from the Tapo API.
Sourcepub async fn get_trigger_logs(
&self,
page_size: u64,
start_id: u64,
) -> Result<TriggerLogsResult<T100Log>, Error>
pub async fn get_trigger_logs( &self, page_size: u64, start_id: u64, ) -> Result<TriggerLogsResult<T100Log>, Error>
Returns a list of trigger logs.
Arguments
page_size- the maximum number of log items to returnstart_id- the log itemidfrom which to start returning results in reverse chronological order (newest first)
Use a start_id of 0 to get the most recent X logs, where X is capped by page_size.